@@ -1,7 +1,7 @@
 package Perinci::Examples::Completion;
 
 our $DATE = '2019-07-19'; # DATE
-our $VERSION = '0.816'; # VERSION
+our $VERSION = '0.817'; # VERSION
 
 use 5.010;
 use strict;
@@ -71,7 +71,7 @@ sub fruits {
     [200, "OK", {@_}];
 }
 
-$SPEC{animal_choice} = {
+$SPEC{animals} = {
     v => 1.1,
     summary => 'Specify an animal (optional) and a color (optional), '.
         'with some examples given in argument spec or schema (for completion)',
@@ -111,7 +111,7 @@ and can be used for testing, documentation, or completion.
 
 _
 };
-sub animal_choice {
+sub animals {
     [200, "OK", {@_}];
 }
 
@@ -130,18 +130,18 @@ Perinci::Examples::Completion - More completion examples
 
 =head1 VERSION
 
-This document describes version 0.816 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-07-19.
+This document describes version 0.817 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-07-19.
 
 =for Pod::Coverage .*
 
 =head1 FUNCTIONS
 
 
-=head2 animal_choice
+=head2 animals
 
 Usage:
 
- animal_choice(%args) -> [status, msg, payload, meta]
+ animals(%args) -> [status, msg, payload, meta]
 
 Specify an animal (optional) and a color (optional), with some examples given in argument spec or schema (for completion).
 
